@@ -12,13 +12,14 @@ use AWS::XRay::Segment;
 use Exporter 'import';
 our @EXPORT_OK = qw/ new_trace_id capture capture_from trace /;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 our $TRACE_ID;
 our $SEGMENT_ID;
 our $ENABLED;
 our $SAMPLED;
 our $SAMPLING_RATE = 1;
+our $SAMPLER       = sub { rand() < $SAMPLING_RATE };
 
 our $DAEMON_HOST = "127.0.0.1";
 our $DAEMON_PORT = 2000;
@@ -37,6 +38,14 @@ sub sampling_rate {
     $SAMPLING_RATE;
 }
 
+sub sampler {
+    my $class = shift;
+    if (@_) {
+        $SAMPLER = shift;
+    }
+    $SAMPLER;
+}
+
 sub sock {
     $Sock //= IO::Socket::INET->new(
         PeerAddr => $DAEMON_HOST || "127.0.0.1",
@@ -71,8 +80,8 @@ sub capture {
         $enabled = 0; # called from parent capture
     } else {
         # root capture try sampling
-        $sampled = rand() < $SAMPLING_RATE ? 1 : 0;
-        $enabled = $sampled ? 1 : 0;
+        $sampled = $SAMPLER->() ? 1 : 0;
+        $enabled = $sampled     ? 1 : 0;
     }
     local $AWS::XRay::ENABLED = $enabled;
     local $AWS::XRay::SAMPLED = $sampled;
@@ -120,7 +129,7 @@ sub capture_from {
     my ($header, $name, $code) = @_;
     my ($trace_id, $segment_id, $sampled) = parse_trace_header($header);
 
-    local $AWS::XRay::SAMPLED = $sampled // rand() < $SAMPLING_RATE;
+    local $AWS::XRay::SAMPLED = $sampled // $SAMPLER->();
     local $AWS::XRay::ENABLED = $AWS::XRay::SAMPLED;
     local($AWS::XRay::TRACE_ID, $AWS::XRay::SEGMENT_ID) = ($trace_id, $segment_id);
     capture($name, $code);
@@ -238,6 +247,18 @@ $rate is allowed a float value between 0 and 1.
 
 When capture_from() called with a trace header includes "Sampled=1", all of followed capture() are traced.
 
+=head2 samplier($code)
+
+Set/Get a code ref to sample for capture().
+
+    AWS::XRay->sampler(sub {
+        if ($some_condition) {
+           return 1;
+        } else {
+           return 0;
+        }
+    });
+
 =head2 AWS_XRAY_DAEMON_ADDRESS environment variable
 
 Set the host and port of the X-Ray daemon. Default 127.0.0.1:2000
